/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeEngstelle!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:37 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterEngstelle
{
	/**
	 * Liste der Straensegmente.
	 */
	private List<SystemObject> m_strassenSegmente = new ArrayList<SystemObject>();
	
	/**
	 * Startoffset der Engstelle in Meter.
	 */
	private long m_startOffset;
	/**
	 * Endoffset der Engstelle in Meter.
	 */
	private long m_endOffset;
	/**
	 * Lnge der Engstelle in Meter.
	 */
	private long m_laenge;
	
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterEngstelle()
	{
	}
	
	/**
	 * Konstruktor mit bernahme der bergebenen Daten in die interne Struktur.
	 */
	public ParameterEngstelle(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			m_strassenSegmente.clear();

			Data data = rdata.getData();
			if (data != null)
			{
				int anzElemente = data.getArray("StraenSegment").getLength();
				for (int i = 0; i < anzElemente; i++)
				{
					m_strassenSegmente.add(data.getReferenceArray("StraenSegment").getSystemObject(i));
				}
				
				m_startOffset = data.getUnscaledValue("StartOffset").longValue();
				m_endOffset = data.getUnscaledValue("EndOffset").longValue();
				m_laenge = data.getUnscaledValue("Lnge").longValue();
			}
		}		
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append(" " + m_strassenSegmente);
		
		return string.toString();
  }

	/**
	 * Gibt die Liste der zugeordneten StraenSegmente zurck.
	 * 
	 * @return Liste der zugeordneten StraenSegmente.
	 */
	public List<SystemObject> getStrassenSegmente()
	{
		return m_strassenSegmente;
	}
	/**
	 * Setzt die Liste der zugeordneten StraenSegmente.
	 * 
	 * @param strassenSegmente zu setzende Liste der StraenSegmente.
	 */
	public void setStrassenSegmente(List<SystemObject> strassenSegmente)
	{
		m_strassenSegmente = strassenSegmente;
	}

	/**
	 * Gibt den Startoffset der Engstelle in Meter zurck.
	 * @return Startoffset der Engstelle in Meter.
	 */
	public long getStartOffset()
	{
		return m_startOffset;
	}

	/**
	 * Setzt den Startoffset der Engstelle in Meter.
	 * @param startOffset zu setzender Wert Startoffset der Engstelle in Meter.
	 */
	public void setStartOffset(long startOffset)
	{
		m_startOffset = startOffset;
	}

	/**
	 * Gibt den Endoffset der Engstelle in Meter zurck.
	 * @return Endoffset der Engstelle in Meter.
	 */
	public long getEndOffset()
	{
		return m_endOffset;
	}

	/**
	 * Setzt den Endoffset der Engstelle in Meter.
	 * @param endOffset zu setzender Wert Endoffset der Engstelle in Meter.
	 */
	public void setEndOffset(long endOffset)
	{
		m_endOffset = endOffset;
	}

	/**
	 * Gibt die Lnge der Engstelle in Meter zurck.
	 * @return Lnge der Engstelle in Meter.
	 */
	public long getLaenge()
	{
		return m_laenge;
	}

	/**
	 * Setzt die Lnge der Engstelle in Meter.
	 * @param laenge zu setzender Wert Lnge der Engstelle in Meter.
	 */
	public void setLaenge(long laenge)
	{
		m_laenge = laenge;
	}
}
