/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeMqZuordnung!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.3 $ / $Date: 2013/07/24 05:24:33 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterMqZuordnung
{
	/**
	 * Liste der zugeordneten Messquerschnitte.
	 */
	private List<SystemObject> m_messQuerschnitte = new ArrayList<SystemObject>();
	
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterMqZuordnung()
	{		
	}
	
	/**
	 * Konstruktor mit bernahme der bergebenen Daten in die interne Struktur.
	 */
	public ParameterMqZuordnung(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			m_messQuerschnitte.clear();

			DataModel dm = rdata.getObject().getDataModel();

			Data data = rdata.getData();
			if (data != null)
			{
				int anzElemente = data.getArray("MessQuerschnitt").getLength();
				for (int i = 0; i < anzElemente; i++)
				{
					SystemObject obj = data.getReferenceArray("MessQuerschnitt").getSystemObject(i);

					if (!obj.isValid())
					{											
						obj = dm.getObject(data.getReferenceArray("MessQuerschnitt").getReferenceValue(i).getValueText());
					}
					
					// virtuelle MQ knnen derzeit wegen fehlender FahrStreifen nicht bearbeitet werden !
					if (obj.getType().getPid().equals("typ.messQuerschnittVirtuell"))
					{
						continue;
					}

					m_messQuerschnitte.add(obj);
				}
			}
		}		
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append(" " + m_messQuerschnitte);
		
		return string.toString();
  }

	/**
	 * Gibt die Liste der zugeordneten Messquerschnitte zurck.
	 * 
	 * @return Liste der zugeordneten Messquerschnitte.
	 */
	public List<SystemObject> getMessQuerschnitte()
	{
		return m_messQuerschnitte;
	}
	/**
	 * Setzt die Liste der zugeordneten Messquerschnitte.
	 * 
	 * @param messQuerschnitte zu setzende Liste der Messquerschnitte.
	 */
	public void setMessQuerschnitte(List<SystemObject> messQuerschnitte)
	{
		m_messQuerschnitte = messQuerschnitte;
	}
}
