/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeUfdmsZuordnung!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.2 $ / $Date: 2012/07/23 06:02:36 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class ParameterUfdmsZuordnung
{
	/**
	 * Liste der zugeordneten Umfelddatenmessstelle.
	 */
	private List<SystemObject> m_umfeldDatenMessStellen = new ArrayList<SystemObject>();
	
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public ParameterUfdmsZuordnung()
	{		
	}
	
	/**
	 * Konstruktor mit bernahme der bergebenen Daten in die interne Struktur.
	 */
	public ParameterUfdmsZuordnung(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			m_umfeldDatenMessStellen.clear();

			Data data = rdata.getData();
			if (data != null)
			{
				int anzElemente = data.getArray("UmfeldDatenMessStelle").getLength();
				for (int i = 0; i < anzElemente; i++)
				{
					m_umfeldDatenMessStellen.add(data.getReferenceArray("UmfeldDatenMessStelle").getSystemObject(i));
				}
			}
		}		
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append(" " + m_umfeldDatenMessStellen);
		
		return string.toString();
  }

	/**
	 * Gibt die Liste der zugeordneten Umfelddatenmessstelle zurck.
	 * 
	 * @return Liste der zugeordneten Umfelddatenmessstelle.
	 */
	public List<SystemObject> getUmfeldDatenMessStellen()
	{
		return m_umfeldDatenMessStellen;
	}
	/**
	 * Setzt die Liste der zugeordneten Umfelddatenmessstelle.
	 * 
	 * @param umfeldDatenMessStellen zu setzende Liste der Umfelddatenmessstelle.
	 */
	public void setUmfeldDatenMessStellen(List<SystemObject> umfeldDatenMessStellen)
	{
		m_umfeldDatenMessStellen = umfeldDatenMessStellen;
	}
}
