/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Entwicklung
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49 (0)7225-64-0
 * Fax: +49 (0)7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.verknuepfung;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.dav.daf.main.ClientDavConnection;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ste.stealgsba.algorithmen.verknuepfung.ParameterVerknuepfung.LogischeVerknuepfung;

/**
 * Diese Klasse speichert die Daten der Attributgruppe !atg.sswSbaUeVerknpfungAnalyse!.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.2 $ / $Date: 2015/03/24 14:40:56 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class VerknuepfungAnalyse
{
	/**
	 * Pid der Attributgruppe.
	 */
	private String m_pidAtg = "atg.sswSbaUeVerknpfungAnalyse";
	
	private List<InputAnalyse> m_input = new ArrayList<InputAnalyse>();
	/**
	 * Logik der Verknpfung.
	 */
	private LogischeVerknuepfung m_logik = LogischeVerknuepfung.UND;
	/**
	 * aktueller Status der Ursacheneinheit.
	 */
	private boolean m_status = false;
	
	/**
	 * Default-Konstruktor der Klasse.
	 */
	public VerknuepfungAnalyse()
	{
		
	}
	
	/**
	 * Erzeugt einen Datensatz der Attributgruppe <code>atg.sswSbaUeVerknpfungAnalyse</code> mit
	 * den Daten der internen Struktur.
	 * 
	 * @param connection Aktuelle Verbindung zum Datenverteiler.
	 * @return erzeugter Datensatz.
	 */
	public Data erzeugeDatensatz(ClientDavConnection connection)
	{
		DataModel dm = connection.getDataModel();		
		Data dataNeu = connection.createData(dm.getAttributeGroup(m_pidAtg));

		if (dataNeu != null)
		{
			dataNeu.getArray("Input").setLength(0);
			
			if (m_input != null)
			{
				for (int i = 0; i < m_input.size(); i++)
				{
					InputAnalyse input = m_input.get(i);

					dataNeu.getArray("Input").setLength(i+1);
					Data element = dataNeu.getArray("Input").getItem(i);
					
					element.getReferenceValue("Ursacheneinheit").setSystemObject(input.getUrsacheneinheit());			
					element.getScaledValue("StatusUe").setText(input.isStatusUe() ? "Ja" : "Nein");								
					element.getScaledValue("InputInvertiert").setText(input.isInputInvertiert() ? "Ja" : "Nein");								
					element.getScaledValue("StatusInput").setText(input.isStatusInput() ? "Ja" : "Nein");								
				}
			}

			dataNeu.getScaledValue("Logik").setText(LogischeVerknuepfung.getText(getLogik()));
			dataNeu.getScaledValue("Status").setText(isStatus() ? "Ja" : "Nein");
			
			return dataNeu;
		}
		
		return null;
	}
	
	/**
	 * Fgt der Liste m_input einen Input mit Analysedaten hinzu.
	 * 
	 * @param ursacheneinheit Referenz auf eine Ursacheneinheit.
	 * @param statusUe aktueller Status Ursacheneinheit Input. 
	 * @param inputInvertiert Kennung Status Input intertieren.
	 * @param statusInput Status unter Bercksichtigung des Schalters Invertierung.
	 */
	public void addInputAnalyse(SystemObject ursacheneinheit, boolean statusUe, boolean inputInvertiert, boolean statusInput)
	{
		if (m_input == null)
		{
			m_input = new ArrayList<VerknuepfungAnalyse.InputAnalyse>();
		}
		
		m_input.add(new InputAnalyse(ursacheneinheit, statusUe, inputInvertiert, statusInput));
	}
	
	/**
	 * Gibt den Wert der Variable m_input zurck.
	 *
	 * @return Wert der Variable m_input.
	 */
	public List<InputAnalyse> getInput()
	{
		return m_input;
	}



	/**
	 * Setzt den Wert der Variable m_input.
	 *
	 * @param input zu setzender Wert der Variable m_input.
	 */
	public void setInput(List<InputAnalyse> input)
	{
		m_input = input;
	}



	/**
	 * Gibt den Wert der Variable m_logik zurck.
	 *
	 * @return Wert der Variable m_logik.
	 */
	public LogischeVerknuepfung getLogik()
	{
		return m_logik;
	}



	/**
	 * Setzt den Wert der Variable m_logik.
	 *
	 * @param logik zu setzender Wert der Variable m_logik.
	 */
	public void setLogik(LogischeVerknuepfung logik)
	{
		m_logik = logik;
	}



	/**
	 * Gibt den Wert der Variable m_status zurck.
	 *
	 * @return Wert der Variable m_status.
	 */
	public boolean isStatus()
	{
		return m_status;
	}



	/**
	 * Setzt den Wert der Variable m_status.
	 *
	 * @param status zu setzender Wert der Variable m_status.
	 */
	public void setStatus(boolean status)
	{
		m_status = status;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString()
	{
		return "VerknuepfungAnalyse [m_input=" + m_input + ", m_logik=" + m_logik + ", m_status=" + m_status + "]";
	}


	/**
	 * 
	 * Innere Klasse zum Speichern der Analysedaten pro Input Ursacheneinheit. 
	 *
	 * @version $Revision: 1.2 $ / $Date: 2015/03/24 14:40:56 $ / ($Author: Asal $)
	 *
	 * @author Swarco Traffic Systems GmbH
	 * @author Rolf Asal
	 *
	 */
	public class InputAnalyse
	{
		/**
		 * Referenz auf eine Ursacheneinheit.
		 */
		private SystemObject m_ursacheneinheit;
		/**
		 * aktueller Status Ursacheneinheit Input. 
		 */
		private boolean m_statusUe;
		/**
		 * Kennung Status Input intertieren.
		 */
		private boolean m_inputInvertiert;
		/**
		 * Status unter Bercksichtigung des Schalters Invertierung.
		 */
		private boolean m_statusInput;
		
		/**
		 * Default-Konstruktor der Klasse.
		 */
		public InputAnalyse()
		{
			
		}

		/**
		 * Konstruktor der Klasse mit bernahme der Parameter.
		 * 
		 * @param ursacheneinheit Referenz auf eine Ursacheneinheit.
		 * @param statusUe aktueller Status Ursacheneinheit Input. 
		 * @param inputInvertiert Kennung Status Input intertieren.
		 * @param statusInput Status unter Bercksichtigung des Schalters Invertierung.
		 */
		public InputAnalyse(SystemObject ursacheneinheit, boolean statusUe, boolean inputInvertiert, boolean statusInput)
		{
			m_ursacheneinheit = ursacheneinheit;
			m_statusUe = statusUe;
			m_inputInvertiert = inputInvertiert;
			m_statusInput = statusInput;
		}

		/**
		 * Gibt den Wert der Variable m_ursacheneinheit zurck.
		 *
		 * @return Wert der Variable m_ursacheneinheit.
		 */
		public SystemObject getUrsacheneinheit()
		{
			return m_ursacheneinheit;
		}

		/**
		 * Setzt den Wert der Variable m_ursacheneinheit.
		 *
		 * @param ursacheneinheit zu setzender Wert der Variable m_ursacheneinheit.
		 */
		public void setUrsacheneinheit(SystemObject ursacheneinheit)
		{
			m_ursacheneinheit = ursacheneinheit;
		}

		/**
		 * Gibt den Wert der Variable m_statusUe zurck.
		 *
		 * @return Wert der Variable m_statusUe.
		 */
		public boolean isStatusUe()
		{
			return m_statusUe;
		}

		/**
		 * Setzt den Wert der Variable m_statusUe.
		 *
		 * @param statusUe zu setzender Wert der Variable m_statusUe.
		 */
		public void setStatusUe(boolean statusUe)
		{
			m_statusUe = statusUe;
		}

		/**
		 * Gibt den Wert der Variable m_inputInvertiert zurck.
		 *
		 * @return Wert der Variable m_inputInvertiert.
		 */
		public boolean isInputInvertiert()
		{
			return m_inputInvertiert;
		}

		/**
		 * Setzt den Wert der Variable m_inputInvertiert.
		 *
		 * @param inputInvertiert zu setzender Wert der Variable m_inputInvertiert.
		 */
		public void setInputInvertiert(boolean inputInvertiert)
		{
			m_inputInvertiert = inputInvertiert;
		}

		/**
		 * Gibt den Wert der Variable m_statusInput zurck.
		 *
		 * @return Wert der Variable m_statusInput.
		 */
		public boolean isStatusInput()
		{
			return m_statusInput;
		}

		/**
		 * Setzt den Wert der Variable m_statusInput.
		 *
		 * @param statusInput zu setzender Wert der Variable m_statusInput.
		 */
		public void setStatusInput(boolean statusInput)
		{
			m_statusInput = statusInput;
		}

		/* (non-Javadoc)
		 * @see java.lang.Object#toString()
		 */
		@Override
		public String toString()
		{
			return "InputAnalyse [m_ursacheneinheit=" + m_ursacheneinheit + ", m_statusUe=" + m_statusUe + ", m_inputInvertiert=" + m_inputInvertiert + ", m_statusInput=" + m_statusInput + "]";
		}
				
	}
}
